@@ -37,8 +37,8 @@
  * either the BSD or the GPL.
  */
 
-#ifndef EVENT_H_
-#define EVENT_H_
+#ifndef EVENT_H__
+#define EVENT_H__
 
 #ifdef EV_H
 # include EV_H
@@ -50,12 +50,6 @@
 extern "C" {
 #endif
 
-/* we need sys/time.h for struct timeval only */
-#if !defined (WIN32) || defined (__MINGW32__)
-# include <time.h> /* mingw seems to need this, for whatever reason */
-# include <sys/time.h>
-#endif
-
 struct event_base;
 
 #define EVLIST_TIMEOUT  0x01
